---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "constellation_image Data Source - constellation"
subcategory: ""
description: |-
  Data source to resolve the CSP-specific OS image reference for a given version and attestation variant.
---

# constellation_image (Data Source)

Data source to resolve the CSP-specific OS image reference for a given version and attestation variant.

## Example Usage

```terraform
data "constellation_image" "example" {
  version             = "v2.13.0"
  attestation_variant = "aws-sev-snp"
  csp                 = "aws"
  region              = "eu-west-1"
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `attestation_variant` (String) Attestation variant the image should work with. Can be one of:
  * `aws-sev-snp`
  * `aws-nitro-tpm`
  * `azure-sev-snp`
  * `gcp-sev-es`
- `csp` (String) CSP (Cloud Service Provider) to use. (e.g. `azure`)
See the [full list of CSPs](https://docs.edgeless.systems/constellation/overview/clouds) that Constellation supports.

### Optional

- `marketplace_image` (Boolean) Whether a marketplace image should be used. Currently only supported for Azure and GCP.
- `region` (String) Region to retrieve the image for. Only required for AWS.
The Constellation OS image must be [replicated to the region](https://docs.edgeless.systems/constellation/workflows/config),and the region must [support AMD SEV-SNP](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/snp-requirements.html), if it is used for Attestation.
- `version` (String) Version of the Constellation OS image to use. (e.g. `v2.13.0`). If not set, the provider version value is used.

### Read-Only

- `image` (Attributes) Constellation OS Image to use on the nodes. (see [below for nested schema](#nestedatt--image))

<a id="nestedatt--image"></a>
### Nested Schema for `image`

Read-Only:

- `reference` (String) CSP-specific unique reference to the image. The format differs per CSP.
- `short_path` (String) CSP-agnostic short path to the image. The format is `vX.Y.Z` for release images and `ref/$GIT_REF/stream/$STREAM/$SEMANTIC_VERSION` for pre-release images.
- `$GIT_REF` is the git reference (i.e. branch name) the image was built on, e.g. `main`.
- `$STREAM` is the stream the image was built on, e.g. `nightly`.
- `$SEMANTIC_VERSION` is the semantic version of the image, e.g. `vX.Y.Z` or `vX.Y.Z-pre...`.
- `version` (String) Semantic version of the image.
